/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "BarInfo.h"
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomBarInfo.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/PrivateGdomBarInfo.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateIntGdomBarInfo.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::BarInfo* obj)
{
    return WebCore::cacheDOMObject<WebCore::BarInfo, GDOMBarInfo>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMBarInfo::GDOMBarInfo(PassRefPtr<WebCore::BarInfo> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMBarInfo::~GDOMBarInfo()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "BarInfo.h"
#include <gdom/GdomBarInfo.h>
#include <gdom/PrivateGdomBarInfo.h>
#include <gdom/PrivateIntGdomBarInfo.h>
#include <gdom/GdomBarInfoprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomBarInfo, gdom_bar_info, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomBarInfoPrivate {
    class WebCore::BarInfo *item;
};

#define GDOM_BAR_INFO_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_BAR_INFO, GdomBarInfoPrivate))
*/
G_END_DECLS
WebCore::BarInfo *
gdom_bar_info_get_private(GdomBarInfo *request)
{
    GDOMBarInfo *res;
    res = static_cast<GDOMBarInfo*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::BarInfo*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_VISIBLE,
};


static void gdom_bar_info_finalize(GObject* object)
{
    /*GdomBarInfo* request = GDOM_BAR_INFO(object);*/
    /*GdomBarInfoPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_bar_info_parent_class)->finalize(object);
}

static void gdom_bar_info__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomBarInfo *self = GDOM_BAR_INFO(object);
    WebCore::BarInfo * gself = (gdom_bar_info_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_bar_info__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomBarInfo *self = GDOM_BAR_INFO(object);
    WebCore::BarInfo * gself = (gdom_bar_info_get_private(self));
    switch (prop_id) {
    case PROP_VISIBLE:
    {
         g_value_set_boolean (value, gself->visible());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_bar_info_class_init(GdomBarInfoClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_bar_info_finalize;
    g_klass->set_property = gdom_bar_info__set_property_fn;
    g_klass->get_property = gdom_bar_info__get_property_fn;

    g_object_class_install_property (g_klass, PROP_VISIBLE,
            g_param_spec_boolean ("visible", /* name */
                "bar_info_visible", /* short description */
                "read-only  gboolean BarInfo.visible", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomBarInfoPrivate));*/
}

static void gdom_bar_info_init(GdomBarInfo* request)
{
    /*GdomBarInfoPrivate* priv = GDOM_BAR_INFO_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

